@@ -5,6 +5,7 @@ Module implementing MainWindow.
 """
 import math
 import sys
+import EXIF
 from PIL import Image, ImageEnhance, ImageDraw
 
 from PyQt4 import QtGui
@@ -69,11 +70,14 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     valMi =0
     valSh =0
     valSa =0
+    valRot = 0
+    valOrient = 0
     wMaximized = True
     lockUpdating = False
     curImageLoc ="ui/resources/landscapeRepo.jpg"
     curIm =""
     curThumb = ""
+    valCurTab=0
         
     def __init__(self, parent = None):
         """
@@ -82,7 +86,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         QMainWindow.__init__(self, parent)
         self.setupUi(self)
         self.ImageOpen(self.curImageLoc)
-    #Comment
+        self.ImageDisplayRefresh()
     
     def showUpdateLabel(self, show,  thumb):
         self.lockUpdating = show
@@ -151,7 +155,10 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        self.LevelApply(self.curIm,  True)
+        if (self.valCurTab == 5):
+            self.RotateApply(self.valRot)
+        else:
+            self.LevelApply(self.curIm,  True)
            
            
     @pyqtSignature("")
@@ -243,6 +250,11 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
+        if (index==7):
+            self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 800, 480))
+        else:
+            self.valCurTab = index
+        
 
     @pyqtSignature("")
     def on_btnLevelReset2_released(self):
@@ -275,12 +287,13 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         if ImgTemp != "":
             self.curImageLoc = ImgTemp
         self.ImageOpen(self.curImageLoc)
-        ImageDisplayOrig()
+        self.ImageDisplayRefresh()
         
-    def ImageDisplayOrig(self):
+    def ImageDisplayRefresh(self):
         """
         Display image on GUI
         """
+        self.ImageLoad(self.curIm)
         self.photo.setPixmap(pil2qpixmap(self.curIm))
         self.photo_Orig.setPixmap(pil2qpixmap(self.curIm))
         self.photo_Thumb.setPixmap(pil2qpixmap(self.curThumb))
@@ -291,12 +304,52 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         self.curIm = Image.open(filename)
         
-        size = 150, 90
-        self.curThumb = Image.open(filename)
-        self.curThumb.thumbnail(size)
-        #self.curThumb = im
+        p = open(filename, "rb")
+        tags = EXIF.process_file(p)
+        for key in tags.keys():
+            try:
+                newItem = str("%s: %s" %(key, tags[key]))
+                
+                if key == "Image Orientation":
+                    if newItem == "Image Orientation: Horizontal (normal)":
+                        self.valOrient = 0
+                    else:
+                        self.valOrient = 1
+                    
+                if (newItem !="" and  newItem.startswith("Maker Note") == False  and  newItem.startswith("MakerNote") == False  and  newItem.startswith("EXIF") == False):
+                    self.listEXIFData.addItem(newItem)
+                    self.listView
+            except Exception, e:
+                print "EXIF Error"
+      
+        self.ImageLoad(self.curIm)
+      
+    def convertImSize(self, origW,  origH,  dConstraint):
+        if (self.valOrient == 0): #landscape
+            scale=origW/dConstraint
+            newW=dConstraint
+            newH=int(math.ceil(origH/scale))
+        else: # portrait
+            scale=origH/dConstraint
+            newH=dConstraint
+            newW=int(math.ceil(origW/scale))
+            
+        return newW,  newH
         
-        self.ImageDisplayOrig()
+    def ImageLoad(self, im):
+        
+        self.curIm = im
+        w, h = self.curIm.size
+        #155, 195 is thumb center
+        wTh,  hTh = self.convertImSize(w, h,  250)
+        
+        self.photo_Thumb.setGeometry(QtCore.QRect(155-int(wTh/2), 195-int(hTh/2), wTh, hTh))
+        
+        size = (wTh,  hTh )
+        self.curThumb = im.resize(size, Image.ANTIALIAS)
+        #self.curThumb.thumbnail(size, Image.ANTIALIAS)
+        # resize makes a copy thumbnail modifies
+        #self.ImageDisplayOrig()
 
 
     @pyqtSignature("int")
@@ -319,13 +372,6 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 #+++++++++++++++++++++++ END of Class    
     
 
-    @pyqtSignature("")
-    def on_btnExit_released(self):
-        """
-        Slot documentation goes here.
-        """
-        sys.exit()
-    
     @pyqtSignature("int")
     def on_cSlide_Hi_valueChanged(self, value):
         """
@@ -388,48 +434,60 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         Slot documentation goes here.
         """
         if  (self.lockUpdating == False):
-            self.showUpdateLabel(True,  True)
-            
-            im = self.curThumb
-            im = im.rotate(value, resample=Image.BICUBIC,  expand=0)
-            w,  h = im.size
-            draw = ImageDraw.Draw(im)
-            theta =math.radians(value)
-             
-            botOps = round(abs(h * math.sin(theta))/2)
-            botAdj = round(abs(h * math.cos(theta))/2)
+            self.valRot = value
+            self.lcdRot_1.setText(str(self.valRot))
+            self.RotateThumb(value)
+           
 
-            topOps = round(abs(w * math.sin(theta))/2)
-            topAdj = round(abs(w * math.cos(theta))/2)
-            
-            theta = theta + math.pi/4
-            if theta >= 6.28:
-                theta = theta - 6.28
-            pi2 = math.pi/2
-            
-            if( theta >= 0.0 and theta < pi2 ): #0 - 1.57 
-                draw.rectangle([botOps,botOps, int(w-botOps),  int(h-botOps)]) 
-                self.lcdRot_1.setText("1")
-            elif( theta >= pi2 and theta < math.pi): # 1.57 - 3.14
-                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
-                self.lcdRot_1.setText("2")
-            elif( theta >= math.pi and theta < (math.pi + pi2) ): # 3.14 - 4.71
-                draw.rectangle([botOps, botOps, int(w-botOps),  int(h-botOps)]) 
-                self.lcdRot_1.setText("3")
-            elif( theta >= (math.pi + pi2)):  # 4.71 - 6.28 ok 
-                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
-                self.lcdRot_1.setText("4")
-            
-            self.lcdRot_2.setText(str(round(theta, 2)))
-            self.lcdRot_bo.setText(str(botOps))
-            self.lcdRot_ba.setText(str(botAdj))
-            self.lcdRot_ta.setText(str(topAdj))
-            self.lcdRot_to.setText(str(topOps))
-            
-            del draw 
-            self.photo_Thumb.setPixmap(pil2qpixmap(im))
-            self.showUpdateLabel(False,  True)
+    def RotateThumb(self, rotation):
+        self.showUpdateLabel(True,  True)
+        im=self.curThumb
+        
+        im = im.rotate(rotation,  resample=Image.BICUBIC,  expand=0)
+        draw = ImageDraw.Draw(im)
+        draw.rectangle(self.RotateCalc(rotation, im))
+        
+        del draw
+        self.photo_Thumb.setPixmap(pil2qpixmap(im))
+        self.showUpdateLabel(False,  True)
+        
+    def RotateApply(self, rotation):
+        self.showUpdateLabel(True,  False)
+        im=self.curIm
+        im = im.rotate(rotation,  resample=Image.BICUBIC,  expand=0)
+        w1, h1, w2, h2 = self.RotateCalc(rotation, im)
+        
+        self.curIm = im.crop((w1, h1, w2, h2))
+        self.ImageDisplayRefresh()
+        self.showUpdateLabel(False,  False)
+        
+    def RotateCalc(self, rotation,  im):
 
+        w,  h = im.size
+        theta =math.radians(rotation)
+
+        botOps = round(abs(h * math.sin(theta))/2)
+        botAdj = round(abs(h * math.cos(theta))/2)
+
+        topOps = round(abs(w * math.sin(theta))/2)
+        topAdj = round(abs(w * math.cos(theta))/2)
+        
+        theta = theta + math.pi/4
+        if theta >= 6.28:
+            theta = theta - 6.28
+        pi2 = math.pi/2
+        
+        if( theta >= 0.0 and theta < pi2 ): #0 - 1.57 
+            return([botOps,botOps, int(w-botOps),  int(h-botOps)]) 
+        elif( theta >= pi2 and theta < math.pi): # 1.57 - 3.14
+            return([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
+        elif( theta >= math.pi and theta < (math.pi + pi2) ): # 3.14 - 4.71
+            return([botOps, botOps, int(w-botOps),  int(h-botOps)]) 
+        elif( theta >= (math.pi + pi2)):  # 4.71 - 6.28 ok 
+            return([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
+
+            
+            
 
 
 #            w, h = im.size
@@ -532,3 +590,16 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         #Enhance(Toplevel(), im, "Sharpness", ImageEnhance.Sharpness, -2.0, 2.0).pack()
         #Enhance(Toplevel(), im, "Brightness", ImageEnhance.Brightness, -1.0, 3.0).pack()
         #Enhance(Toplevel(), im, "Contrast", ImageEnhance.Contrast, -1.0, 3.0).pack()
+
+
+#cp -r  /home/user/MyDocs/code/svn/ansela/trunk/* /home/user/MyDocs/code/svn/ansela/packaging/anselA/src/opt/anselA/
+    
+    
+    @pyqtSignature("")
+    def on_btnExitCancel_released(self):
+        self.tabStrip.setCurrentIndex(self.valCurTab)
+        self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
+        
+    @pyqtSignature("")
+    def on_btnExitGo_released(self):
+        sys.exit()
